%define pfix_ver 2.1.5
%define ipv6_tls 1.25
%define spf2 2.1.3-4

Summary:     The Postfix MTA
Name:        postfix
Version:     %{pfix_ver}
Release:     4.pp
License:     IBM Public License
Group:       System Environment/Daemons
Source0:     ftp://ftp.porcupine.org/mirrors/%{name}-release/official/%{name}-%{version}.tar.gz
Source1:     %{name}.init
Source2:     %{name}.aliases
Source3:     %{name}-chroot-setup.awk
Patch0:      ftp://ftp.stack.nl/pub/%{name}/tls+ipv6/%{ipv6_tls}/tls+ipv6-%{ipv6_tls}-pf-%{pfix_ver}.patch.gz
Patch1:      ftp://ftp.stack.nl/pub/%{name}/spf/current/%{name}-libspf2-%{spf2}.patch
Patch2:      %{name}-alternatives.patch
Patch3:      %{name}-config.patch
Patch4:      %{name}-smtp_sasl_proto.c.patch
Patch5:      %{name}+pam.patch
URL:         http://www.%{name}.org/
Buildroot:   /var/tmp/%{name}-root
Vendor:      Wietse Venema
Packager:    Peter Pramberger <peter.pramberger@member.fsf.org>
Provides:    %{name}.pp MTA smtpd smtpdaemon /usr/sbin/sendmail /usr/bin/mailq /usr/bin/rmail
Obsoletes:   sendmail exim qmail
Conflicts:   sendmail sendmail-client
Requires:    openssl097 db4 >= 4.2 openldap22 pam cyrus-sasl2 libspf2
Prereq:      /bin/bash /usr/sbin/useradd /usr/sbin/groupadd /sbin/chkconfig
Prereq:      /sbin/service sh-utils fileutils textutils /usr/sbin/alternatives
BuildPrereq: gcc /bin/mkdir /usr/bin/make /usr/bin/install
BuildPrereq: gawk perl sed ed db4-devel >= 4.2 openldap22-devel pam-devel
BuildPrereq: pcre-devel cyrus-sasl2-devel openssl097-devel libspf2-devel
ExclusiveOS: linux


%description
Postfix is an attempt to provide an alternative to the widely-used
Sendmail program. Postfix attempts to be fast, easy to administer,
and hopefully secure, while at the same time being sendmail compatible
enough to not upset your users.


%prep
umask 022
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p2
# Move around TLS docs
mkdir html/TLS
mv pfixtls/doc/* html/TLS
for i in ACKNOWLEDGEMENTS CHANGES INSTALL README TODO; do
   mv pfixtls/$i $i.TLS
done
# Setup master.cf to be chrooted
mv conf/master.cf conf/master.cf-nochroot
awk -f $RPM_SOURCE_DIR/postfix-chroot-setup.awk < conf/master.cf-nochroot > conf/master.cf


%build
umask 022
CCARGS="-DFD_SETSIZE=2048 -DHAS_LDAP -DHAS_PCRE -I/usr/include/pcre -DUSE_SASL_AUTH -I/usr/include/sasl -DHAS_SSL -I/usr/include/openssl -I/usr/kerberos/include -DHAS_PAM"
AUXLIBS="-L/usr/lib -L/usr/kerberos/lib -lldap -llber -lpcre -lsasl2 -lssl -lcrypto -lpam -lspf2"
export CCARGS AUXLIBS
make -f Makefile.init makefiles
unset CCARGS AUXLIBS
make DEBUG="" OPT="$RPM_OPT_FLAGS"


%define __os_install_post /usr/lib/rpm/brp-compress


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/var/spool/postfix/etc/pam.d
mkdir -p $RPM_BUILD_ROOT/var/spool/postfix/lib
mkdir -p $RPM_BUILD_ROOT/var/spool/postfix/proc
mkdir -p $RPM_BUILD_ROOT/var/spool/postfix/usr/kerberos/lib
mkdir -p $RPM_BUILD_ROOT/var/spool/postfix/usr/lib/zoneinfo
mkdir -p $RPM_BUILD_ROOT/var/spool/postfix/usr/lib/sasl2
for i in active bounce corrupt defer deferred flush hold incoming private saved trace maildrop public pid; do
   mkdir -p $RPM_BUILD_ROOT/var/spool/postfix/$i
done
# Install postfix into $RPM_BUILD_ROOT
sh postfix-install -non-interactive                 \
	install_root=$RPM_BUILD_ROOT                \
	config_directory=/etc/postfix               \
	daemon_directory=/usr/libexec/postfix       \
	command_directory=/usr/sbin                 \
	queue_directory=/var/spool/postfix          \
	sendmail_path=/usr/sbin/sendmail.postfix    \
	newaliases_path=/usr/bin/newaliases.postfix \
	mailq_path=/usr/bin/mailq.postfix           \
	mail_owner=postfix                          \
	setgid_group=postdrop                       \
	manpage_directory=/usr/share/man            \
	sample_directory=/samples                   \
	readme_directory=/etc/postfix/README_FILES || exit 1
install -c auxiliary/rmail/rmail $RPM_BUILD_ROOT/usr/bin/rmail
# Change alias_maps and alias_database default directory to /etc/postfix
bin/postconf -c $RPM_BUILD_ROOT/etc/postfix -e       \
	"alias_maps = hash:/etc/postfix/aliases"     \
	"alias_database = hash:/etc/postfix/aliases" || exit 1
# Init script
install -c $RPM_SOURCE_DIR/postfix.init $RPM_BUILD_ROOT/etc/rc.d/init.d/postfix
# Copy new aliases files and generate a ghost aliases.db file
cp -f $RPM_SOURCE_DIR/postfix.aliases $RPM_BUILD_ROOT/etc/postfix/aliases
chmod 644 $RPM_BUILD_ROOT/etc/postfix/aliases
touch $RPM_BUILD_ROOT/etc/postfix/aliases.db
# Install smtp-sink/smtp-source by hand
for i in smtp-sink smtp-source; do
   install -c -m 755 bin/$i $RPM_BUILD_ROOT/usr/sbin/
done
# Move stuff around so we don't conflict with sendmail
mv $RPM_BUILD_ROOT/usr/bin/rmail $RPM_BUILD_ROOT/usr/bin/rmail.postfix
mv $RPM_BUILD_ROOT/usr/share/man/man1/mailq.1 $RPM_BUILD_ROOT/usr/share/man/man1/mailq.postfix.1
mv $RPM_BUILD_ROOT/usr/share/man/man1/newaliases.1 $RPM_BUILD_ROOT/usr/share/man/man1/newaliases.postfix.1
mv $RPM_BUILD_ROOT/usr/share/man/man5/aliases.5 $RPM_BUILD_ROOT/usr/share/man/man5/aliases.postfix.5
# RPM compresses man pages automatically.
# - Edit postfix-files to reflect this, so post-install won't get confused
#   when called during package installation.
ed $RPM_BUILD_ROOT/etc/postfix/postfix-files <<EOF || exit 1
%s/\(\/man[158]\/.*\.[158]\):/\1.gz:/
w
q
EOF


%pre
# Add user and groups if necessary
/usr/sbin/groupadd -g 90 -r postdrop 2>/dev/null || :
/usr/sbin/groupadd -g 89 -r postfix 2>/dev/null || :
/usr/sbin/groupadd -g 12 -r mail 2>/dev/null || :
/usr/sbin/useradd -d /var/spool/postfix -s /bin/true \
	-g postfix -G mail -M -r -u 89 postfix 2>/dev/null || :


%post
umask 022
/sbin/chkconfig --add postfix
# Upgrade configuration files if necessary
sh /etc/postfix/post-install                       \
	config_directory=/etc/postfix              \
	daemon_directory=/usr/libexec/postfix      \
	command_directory=/usr/sbin                \
	mail_owner=postfix                         \
	setgid_group=postdrop                      \
	manpage_directory=/usr/share/man           \
	sample_directory=/usr/share/doc/%{name}-%{version}/samples \
	readme_directory=/etc/postfix/README_FILES \
	upgrade-package
# Setup chroot config
mkdir -p /var/spool/postfix/etc
[ -e /etc/localtime ] && cp /etc/localtime /var/spool/postfix/etc
[ -e /etc/hosts ] && cp /etc/hosts /var/spool/postfix/etc
echo /usr/kerberos/lib >> /var/spool/postfix/etc/ld.so.conf
# Alternatives
/usr/sbin/alternatives \
	--install /usr/sbin/sendmail mta /usr/sbin/sendmail.postfix 30 \
	--slave /usr/bin/mailq mta-mailq /usr/bin/mailq.postfix \
	--slave /usr/bin/newaliases mta-newaliases /usr/bin/newaliases.postfix \
	--slave /usr/bin/rmail mta-rmail /usr/bin/rmail.postfix \
	--slave /usr/share/man/man1/mailq.1.gz mta-mailqman /usr/share/man/man1/mailq.postfix.1.gz \
	--slave /usr/share/man/man1/newaliases.1.gz mta-newaliasesman /usr/share/man/man1/newaliases.postfix.1.gz \
	--slave /usr/share/man/man5/aliases.5.gz mta-aliasesman /usr/share/man/man5/aliases.postfix.5.gz \
	--initscript postfix


# Generate chroot jails on the fly when needed things are installed/upgraded
%triggerin -- glibc
# Kill off old versions
for i in compat dns files hesiod nis nisplus winbind wins; do
   rm -rf /var/spool/postfix/lib/libnss_$i*
done
rm -rf /var/spool/postfix/lib/libc.so*
rm -rf /var/spool/postfix/lib/libresolv*
rm -rf /var/spool/postfix/lib/libnsl*
rm -rf /var/spool/postfix/lib/libdl*
rm -rf /var/spool/postfix/lib/libcrypt-*
rm -rf /var/spool/postfix/lib/ld-*
rm -rf /var/spool/postfix/lib/libpthread*
# Copy the relevant parts in
LIBCVER=`ls -l /lib/libc.so.6* | sed "s/.*libc-\(.*\).so$/\1/g"`
for i in compat dns files hesiod nis nisplus winbind wins; do
   [ -e /lib/libnss_$i-${LIBCVER}.so ] && cp -pf /lib/libnss_$i-${LIBCVER}.so /var/spool/postfix/lib
   [ -e /lib/libnss_$i.so ] && cp -pf /lib/libnss_$i.so /var/spool/postfix/lib
done
cp -f /lib/libc.so.6* /var/spool/postfix/lib
cp -pf /lib/libresolv-${LIBCVER}.so /var/spool/postfix/lib
cp -pf /lib/libnsl-${LIBCVER}.so /var/spool/postfix/lib
cp -pf /lib/libdl-${LIBCVER}.so /var/spool/postfix/lib
cp -pf /lib/libcrypt-${LIBCVER}.so /var/spool/postfix/lib
cp -pf /lib/ld-${LIBCVER}.so /var/spool/postfix/lib
cp -pf /lib/libpthread-*.so /var/spool/postfix/lib
ldconfig -n /var/spool/postfix/lib

%triggerin -- openldap22
rm -rf /var/spool/postfix/usr/lib/liblber*-2* /var/spool/postfix/usr/lib/libldap*-2* /var/spool/postfix/usr/lib/libslapi*-2*
cp -pf /usr/lib/liblber-2*.so.*.* /var/spool/postfix/usr/lib
cp -pf /usr/lib/libldap_r-2*.so.*.* /var/spool/postfix/usr/lib
cp -pf /usr/lib/libldap-2*.so.*.* /var/spool/postfix/usr/lib
cp -pf /usr/lib/libslapi-2*.so.*.* /var/spool/postfix/usr/lib
ldconfig -n /var/spool/postfix/usr/lib

%triggerin -- openssl097
rm -rf /var/spool/postfix/usr/lib/libssl.so.0.9.7 /var/spool/postfix/usr/lib/libcrypto.so.0.9.7
cp -pf /usr/lib/libcrypto.so.0.9.7 /var/spool/postfix/usr/lib
cp -pf /usr/lib/libssl.so.0.9.7 /var/spool/postfix/usr/lib
ldconfig -n /var/spool/postfix/lib

%triggerin -- pam
rm -rf /var/spool/postfix/lib/libpam* /var/spool/postfix/lib/security
cp -pf /lib/libpamc.so.*.* /var/spool/postfix/lib
cp -pf /lib/libpam_misc.so.*.* /var/spool/postfix/lib
cp -pf /lib/libpam.so.*.* /var/spool/postfix/lib
cp -rdf /lib/security /var/spool/postfix/lib
cp -pf /etc/pam.d/other /var/spool/postfix/etc/pam.d
ldconfig -n /var/spool/postfix/lib

%triggerin -- cyrus-sasl2
rm -rf /var/spool/postfix/usr/lib/libsasl2* /var/spool/postfix/usr/lib/sasl2/libanonymous*
cp -pf /usr/lib/libsasl2.so.*.* /var/spool/postfix/usr/lib
cp -pf /usr/lib/sasl2/libanonymous.so.*.* /var/spool/postfix/usr/lib/sasl2
cp -df /usr/lib/sasl2/libanonymous.so /var/spool/postfix/usr/lib/sasl2
ldconfig -n /var/spool/postfix/usr/lib
ldconfig -n /var/spool/postfix/usr/lib/sasl2

%triggerin -- cyrus-sasl2-plain
rm -rf /var/spool/postfix/usr/lib/sasl2/liblogin* /var/spool/postfix/usr/lib/sasl2/libplain*
cp -pf /usr/lib/sasl2/liblogin.so.*.* /var/spool/postfix/usr/lib/sasl2
cp -pf /usr/lib/sasl2/libplain.so.*.* /var/spool/postfix/usr/lib/sasl2
cp -df /usr/lib/sasl2/liblogin.so /var/spool/postfix/usr/lib/sasl2
cp -df /usr/lib/sasl2/libplain.so /var/spool/postfix/usr/lib/sasl2
ldconfig -n /var/spool/postfix/usr/lib/sasl2

%triggerin -- cyrus-sasl2-md5
rm -rf /var/spool/postfix/usr/lib/sasl2/libcrammd5* /var/spool/postfix/usr/lib/sasl2/libdigestmd5*
cp -pf /usr/lib/sasl2/libcrammd5.so.*.* /var/spool/postfix/usr/lib/sasl2
cp -pf /usr/lib/sasl2/libdigestmd5.so.*.* /var/spool/postfix/usr/lib/sasl2
cp -df /usr/lib/sasl2/libcrammd5.so /var/spool/postfix/usr/lib/sasl2
cp -df /usr/lib/sasl2/libdigestmd5.so /var/spool/postfix/usr/lib/sasl2
ldconfig -n /var/spool/postfix/usr/lib/sasl2

%triggerin -- cyrus-sasl2-gssapi
rm -rf /var/spool/postfix/usr/lib/sasl2/libgssapiv2*
cp -pf /usr/lib/sasl2/libgssapiv2.so.*.* /var/spool/postfix/usr/lib/sasl2
cp -df /usr/lib/sasl2/libgssapiv2.so /var/spool/postfix/usr/lib/sasl2
ldconfig -n /var/spool/postfix/usr/lib/sasl2

%triggerin -- krb5-libs
rm -rf /var/spool/postfix/etc/krb5.conf
rm -rf /var/spool/postfix/usr/kerberos/lib/*
cp -pf /etc/krb5.conf /var/spool/postfix/etc
cp -pf /usr/kerberos/lib/* /var/spool/postfix/usr/kerberos/lib

%triggerin -- libspf2
rm -rf /var/spool/postfix/usr/lib/libspf2*
cp -pf /usr/lib/libspf2.so.*.* /var/spool/postfix/usr/lib

%triggerin -- libsafe
rm -rf /var/spool/postfix/lib/libsafe* /var/spool/postfix/etc/ld.so.preload
cp -pf /lib/libsafe.so.*.* /var/spool/postfix/lib
echo `ls /lib/libsafe.so.?` > /var/spool/postfix/etc/ld.so.preload 2>/dev/null
ldconfig -n /var/spool/postfix/lib

%triggerin -- nss_lwres
rm -rf /var/spool/postfix/lib/libnss_lwres*
cp -pf /lib/libnss_lwres.so.*.* /var/spool/postfix/lib
ldconfig -n /var/spool/postfix/lib

%triggerin -- bind-utils
rm -rf /var/spool/postfix/usr/lib/libdns*
rm -rf /var/spool/postfix/usr/lib/libisc*
rm -rf /var/spool/postfix/usr/lib/liblwres*
rm -rf /var/spool/postfix/usr/lib/libidnkit*
cp -pf /usr/lib/libdns.so.*.* /var/spool/postfix/usr/lib
cp -pf /usr/lib/libisc*.so.*.* /var/spool/postfix/usr/lib
cp -pf /usr/lib/liblwres.so.*.* /var/spool/postfix/usr/lib
cp -pf /usr/lib/libidnkit*.so.*.* /var/spool/postfix/usr/lib
ldconfig -n /var/spool/postfix/usr/lib

%triggerin -- setup
rm -f /var/spool/postfix/etc/services
rm -f /var/spool/postfix/etc/protocols
rm -f /var/spool/postfix/etc/nsswitch.conf
rm -f /var/spool/postfix/etc/hosts
cp -pf /etc/services /var/spool/postfix/etc
cp -pf /etc/protocols /var/spool/postfix/etc
cp -pf /etc/nsswitch.conf /var/spool/postfix/etc
cp -pf /etc/hosts /var/spool/postfix/etc

# Put db4 in the chroot jail, but only if the soname is correct
%triggerin -- db4
DBVER=`ldd /usr/libexec/postfix/pickup | grep libdb | perl -pi -e "s,\s+,,g;s,=>.*,,"`
if [ -e "/usr/lib/$DBVER" ]; then
   cp -pf "/usr/lib/$DBVER" /var/spool/postfix/usr/lib
fi


%preun
umask 022
# Selectively remove the rest of the queue directory structure
# First remove the "queues" (and assume the hash depth is still 2)
queue_directory_remove () {
   for dir in active bounce defer deferred flush hold incoming; do
      for a in 0 1 2 3 4 5 6 7 8 9 A B C D E F; do
         test -d $dir/$a && {
            for b in 0 1 2 3 4 5 6 7 8 9 A B C D E F; do
               test -d $dir/$a/$b && (
                  /bin/rm -f $dir/$a/$b/*
                  /bin/rmdir $dir/$a/$b
               )
            done
            /bin/rmdir $dir/$a || echo "WARNING: preun - unable to remove directory /var/spool/postfix/$dir/$a"
         }
      done
      /bin/rmdir $dir || echo "WARNING: preun - unable to remove directory /var/spool/postfix/$dir"
   done
   # Now remove the other directories
   for dir in corrupt maildrop pid private public saved trace; do
      test -d $dir && {
         /bin/rm -f $dir/*
         /bin/rmdir $dir || echo "WARNING: preun - unable to remove directory /var/spool/postfix/$dir"
      }
   done
}
if [ "$1" = 0 ]; then
   # Stop postfix silently, but only if it's running
   /sbin/service postfix stop &>/dev/null
   /sbin/chkconfig --del postfix
   /usr/sbin/alternatives --remove mta /usr/sbin/sendmail.postfix
   cd /var/spool/postfix && {
      # Clean up chroot environment
      rm -rf /var/spool/postfix/lib /var/spool/postfix/usr /var/spool/postfix/etc /var/spool/postfix/proc
      queue_directory_remove
   }
   true # to ensure we exit safely
fi
# Remove unneeded symbolic links
test -L /etc/postfix/README_FILES && rm /etc/postfix/README_FILES || true


%postun         
if [ "$1" != 0 ]; then
   /sbin/service postfix condrestart 2>&1 > /dev/null
fi
exit 0


%clean
rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc AAAREADME COMPATIBILITY COPYRIGHT HISTORY INSTALL LICENSE PORTING
%doc README_FILES RELEASE_NOTES* SPF-ChangeLog US_PATENT_6321267
%doc ACKNOWLEDGEMENTS.TLS CHANGES.TLS README.TLS TODO.TLS
%doc %dir html
%config %dir /etc/postfix
%attr(0644,root,root) /etc/postfix/LICENSE
%attr(0755,root,root) %config /etc/postfix/postfix-script
%attr(0755,root,root) %config /etc/postfix/post-install
%attr(0644,root,root) /etc/postfix/postfix-files
%attr(0644,root,root) %config(noreplace) /etc/postfix/main.cf
%attr(0644,root,root) /etc/postfix/main.cf.default
%attr(0644,root,root) %config(noreplace) /etc/postfix/master.cf
%attr(0644,root,root) %config(noreplace) /etc/postfix/access
%attr(0644,root,root) %config(noreplace) /etc/postfix/aliases
%attr(0644,root,root) %ghost /etc/postfix/aliases.db
%attr(0644,root,root) %config(noreplace) /etc/postfix/canonical
%attr(0644,root,root) %config(noreplace) /etc/postfix/header_checks
%attr(0644,root,root) %config(noreplace) /etc/postfix/relocated
%attr(0644,root,root) %config(noreplace) /etc/postfix/transport
%attr(0644,root,root) %config(noreplace) /etc/postfix/virtual
%attr(0644,root,root) %config(noreplace) /etc/postfix/makedefs.out
%dir %attr(-,root,root) /etc/postfix/README_FILES
%attr(0644,root,root) /etc/postfix/README_FILES/*
%attr(0755,root,root) %config /etc/rc.d/init.d/postfix
%dir /var/spool/postfix
%dir %attr(-,root,root) /var/spool/postfix/etc
%dir %attr(-,root,root) /var/spool/postfix/etc/pam.d
%dir %attr(-,root,root) /var/spool/postfix/lib
%dir %attr(-,root,root) /var/spool/postfix/proc
%attr(-,root,root) /var/spool/postfix/usr
# For correct directory permissions check postfix-install script
%dir %attr(0700,postfix,root) /var/spool/postfix/active
%dir %attr(0700,postfix,root) /var/spool/postfix/bounce
%dir %attr(0700,postfix,root) /var/spool/postfix/corrupt
%dir %attr(0700,postfix,root) /var/spool/postfix/defer
%dir %attr(0700,postfix,root) /var/spool/postfix/deferred
%dir %attr(0700,postfix,root) /var/spool/postfix/flush
%dir %attr(0700,postfix,root) /var/spool/postfix/hold
%dir %attr(0700,postfix,root) /var/spool/postfix/incoming
%dir %attr(0700,postfix,root) /var/spool/postfix/private
%dir %attr(0700,postfix,root) /var/spool/postfix/saved
%dir %attr(0700,postfix,root) /var/spool/postfix/trace
%dir %attr(0730,postfix,postdrop) /var/spool/postfix/maildrop
%dir %attr(0710,postfix,postdrop) /var/spool/postfix/public
%dir %attr(0755,root,root) /var/spool/postfix/pid
%dir %attr(0755,root,root) /usr/libexec/postfix
/usr/libexec/postfix/*
/usr/sbin/postalias
/usr/sbin/postcat
/usr/sbin/postconf
%attr(2755,root,postdrop) /usr/sbin/postdrop
%attr(2755,root,postdrop) /usr/sbin/postqueue
/usr/sbin/postfix
/usr/sbin/postkick
/usr/sbin/postlock
/usr/sbin/postlog
/usr/sbin/postmap
/usr/sbin/postsuper
/usr/sbin/smtp-sink
/usr/sbin/smtp-source
/usr/sbin/sendmail.postfix
/usr/bin/mailq.postfix
/usr/bin/newaliases.postfix
%attr(0755,root,root) /usr/bin/rmail.postfix
/usr/share/man/man1/*
/usr/share/man/man5/*
/usr/share/man/man8/*


%changelog
* Sat Sep 25 2004 peter.pramberger@member.fsf.org
- new version 2.1.5
- added SPF support

* Thu Mar 18 2004 peter.pramberger@member.fsf.org
- new version 2.0.19

* Wed Feb 03 2004 peter.pramberger@member.fsf.org
- new version 2.0.18

* Sat Sep 20 2003 peter.pramberger@member.fsf.org
- new version 2.0.16
- added ipv6+tls patch
- added pam support patch
- added NS+MX acl patch

* Sat Jun 14 2003 peter.pramberger@member.fsf.org
- created (from original rh spec)

